@@ -47,9 +47,9 @@ def TYPE(*args, color='33', status=0):
                     for i in range(len(msg)):
                         if WindowsOS:
                             if color == '33':
-                                wp.printyellow(str(msg[i]+"\n"))
+                                wp.printyellow(str(msg[i])+"\n")
                             elif color == '31':
-                                wp.printred(str(msg[i]+"\n"))
+                                wp.printred(str(msg[i])+"\n")
                         elif LinuxOS:
                             temp = "\033[%sm " %(color) + str(msg[i]) + "\033[0m"
                             print(temp)
@@ -58,7 +58,7 @@ def TYPE(*args, color='33', status=0):
                 else:
                     if WindowsOS:
                         if color == '33':
-                            wp.printyellow(str(msg+"\n"))
+                            wp.printyellow(str(msg)+"\n")
                         elif color == '31':
                             wp.printred(str(msg)+"\n")
                     elif LinuxOS:
